pub fn create_ibm_client(_token: &str) -> DeviceResult<()>Expand description
Create an IBM Quantum client
This function is available as a stub when the “ibm” feature is not enabled
pub fn create_ibm_client(_token: &str) -> DeviceResult<()>Create an IBM Quantum client
This function is available as a stub when the “ibm” feature is not enabled